@@ -2,11 +2,13 @@ from __future__ import annotations
 
 from collections.abc import Sequence
 from functools import lru_cache
-from typing import TYPE_CHECKING, Any, Callable, Final, get_type_hints
+from typing import TYPE_CHECKING, Any, Final, get_type_hints
 
 from polars._dependencies import _check_for_pydantic, pydantic
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     import pandas as pd
 
 PANDAS_SIMPLE_NUMPY_DTYPES: Final[set[str]] = {
