@@ -9,7 +9,7 @@ from datetime import time
 from glob import glob
 from io import BufferedReader, BytesIO, StringIO, TextIOWrapper
 from pathlib import Path
-from typing import IO, TYPE_CHECKING, Any, Callable, NoReturn, overload
+from typing import IO, TYPE_CHECKING, Any, NoReturn, overload
 
 import polars._reexport as pl
 from polars import from_arrow
@@ -43,6 +43,7 @@ from polars.io._utils import looks_like_url, process_file_url
 from polars.io.csv.functions import read_csv
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
     from typing import Literal
 
     from polars._typing import ExcelSpreadsheetEngine, FileSource, SchemaDict
@@ -1077,11 +1078,17 @@ def _read_spreadsheet_calamine(
         df = ws.to_polars()
     else:
         if table_name:
+            if col_names := read_options.get("use_columns"):
+                selected_col_names = set(col_names)
+                read_options["use_columns"] = lambda col: col.name in selected_col_names
+
             xl_table = parser.load_table(table_name, **read_options)
+
             if sheet_name and sheet_name != xl_table.sheet_name:
                 msg = f"table named {table_name!r} not found in sheet {sheet_name!r}"
                 raise RuntimeError(msg)
             df = xl_table.to_polars()
+
         elif _PYARROW_AVAILABLE:
             # eager loading is faster / more memory-efficient, but requires pyarrow
             ws_arrow = parser.load_sheet_eager(sheet_name, **read_options)
@@ -1157,7 +1164,9 @@ def _read_spreadsheet_calamine(
     if type_checks:
         apply_cast = df.select(d[0].all(ignore_nulls=True) for d in type_checks).row(0)
         if downcast := [
-            cast for apply, (_, cast) in zip(apply_cast, type_checks) if apply
+            cast
+            for apply, (_, cast) in zip(apply_cast, type_checks, strict=True)
+            if apply
         ]:
             df = df.with_columns(*downcast)
 
@@ -1233,7 +1242,7 @@ def _read_spreadsheet_openpyxl(
 
     dtype = String if no_inference else None
     series_data = []
-    for name, column_data in zip(header, zip(*rows_iter)):
+    for name, column_data in zip(header, zip(*rows_iter, strict=False), strict=False):
         if name or not drop_empty_cols:
             values = [cell.value for cell in column_data]
             if no_inference or (dtype := schema_overrides.get(name)) == String:  # type: ignore[assignment,arg-type]
@@ -1261,7 +1270,7 @@ def _read_spreadsheet_openpyxl(
 
     names = deduplicate_names(s.name for s in series_data)
     df = pl.DataFrame(
-        dict(zip(names, series_data)),
+        dict(zip(names, series_data, strict=True)),
         schema_overrides=schema_overrides,
         infer_schema_length=infer_schema_length,
         strict=False,
