@@ -1,10 +1,9 @@
 from __future__ import annotations
 
 import contextlib
-import sys
 from collections import OrderedDict
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Literal, Union, overload
+from typing import TYPE_CHECKING, Literal, overload
 
 from polars._typing import PythonDataType
 from polars._utils.unstable import unstable
@@ -22,36 +21,22 @@ with contextlib.suppress(ImportError):  # Module not available when building doc
 
 if TYPE_CHECKING:
     from collections.abc import Iterable
+    from typing import TypeAlias
 
     import pyarrow as pa
 
     from polars import DataFrame, LazyFrame
     from polars._typing import ArrowSchemaExportable
-
-    if sys.version_info >= (3, 10):
-        from typing import TypeAlias
-    else:
-        from typing_extensions import TypeAlias
 else:
     from polars._dependencies import pyarrow as pa
 
 
-if sys.version_info >= (3, 10):
-
-    def _required_init_args(tp: DataTypeClass) -> bool:
-        # note: this check is ~20% faster than the check for a
-        # custom "__init__", below, but is not available on py39
-        return bool(tp.__annotations__)
-else:
-
-    def _required_init_args(tp: DataTypeClass) -> bool:
-        # indicates override of the default __init__
-        # (eg: this type requires specific args)
-        return "__init__" in tp.__dict__
+def _required_init_args(tp: DataTypeClass) -> bool:
+    return bool(tp.__annotations__)
 
 
 BaseSchema = OrderedDict[str, DataType]
-SchemaInitDataType: TypeAlias = Union[DataType, DataTypeClass, PythonDataType]
+SchemaInitDataType: TypeAlias = DataType | DataTypeClass | PythonDataType
 
 __all__ = ["Schema"]
 
@@ -157,7 +142,7 @@ class Schema(BaseSchema):
             return False
         if len(self) != len(other):
             return False
-        for (nm1, tp1), (nm2, tp2) in zip(self.items(), other.items()):
+        for (nm1, tp1), (nm2, tp2) in zip(self.items(), other.items(), strict=True):
             if nm1 != nm2 or not tp1.is_(tp2):
                 return False
         return True
